<?php

namespace App\Http\Controllers\API\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Appuser;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use App\Mail\ForgotPassworMail;
use Validator, Auth, DB, Hash, Mail;

class UserController extends Controller
{
    protected $guard;

    public function store(Request $request)
    {
        $data = $request->all();
        // dd($data);
        $rules = [
            'name' => ['required', 'string', 'min:3', 'max:50'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:app_users'],
            'password' => ['required', 'string', 'max:50'],
            'mobile' => ['required', 'string', 'min:10', 'max:10', 'unique:app_users']
        ];

        $message = [
            'name.required' => 'Name field is required.',
            'email.required' => 'Email field is required.',
            'email.email' => 'Email must be valid format.',
            'password.required' => 'Password field is required.',
            'mobile.required' => 'Mobile field is required.',
            'mobile.min' => 'Mobile number use 10 digit minimum',
            'mobile.max' => 'Mobile number use 10 digit minimum',
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            $response['status'] = false; 
            $response['message'] = "Validation errors";
            $response['error'] = $validator->errors();
            $response['data'] = []; 
            return response()->json(['result' => $response], 422);
        }

        $userStore = new Appuser;
        $userStore->name = $data['name'];
        $userStore->email = $data['email'];
        $userStore->password = Hash::make($data['password']);
        $userStore->mobile = $data['mobile'];
        $userStore->status = 707;

        $userStore->save();

        $UserObj = Appuser::where(["email" => $data['email']])->first();

        if ($UserObj) {
            $response['status'] = true;
            $response['message'] = (isset($UserObj->email))?"You have  been registered successfully, Please verify your email address.":"User has been registered successfully";
            return response()->json(['result' => $response], 201);
        }else{
            $response['status'] = false; 
            $response['message'] = "Something went wrong. Please Try again."; 
            $response['data'] = [];
            return response()->json(['result' => $response], 422);
        }
    }

    public function login(Request $request){
        $data = $request->all();
        $rules = [
            'email' => ['required', 'string', 'email'],
            'password' => ['required', 'string']
        ];

        $message = [
            'name.required' => 'Name field is required.',
            'email.required' => 'Email field is required.',
            'email.email' => 'Email must be valid format.',
            'password.required' => 'Password field is required.',
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            $response['status'] = false; 
            $response['message'] = "Login validation errors";
            $response['error'] = $validator->errors();
            $response['data'] = [];
            return response()->json(['result' => $response], 422);
        }
        $checkUserType = \Request::segment(3);
        $loginUserType = "";
        if($checkUserType == 'user'){
            $loginUserType = 'app-user-api';
        }else{
            $loginUserType = 'teachers';
        }

        $user = Appuser::where('email', $request->email)->first();
        if($user){
            if (Hash::check($request->password, $user->password)) {
                $token = $user->createToken('user Token', ['appuser'])->accessToken;
                $result['status']  =  true;
                $result['message']  =  "Success! you are logged in successfully";
                $result['token']    =  $token;
                return response()->json(['result' => $result], 200);
            }else{
                $result['status']  =  false;
                $result['message']  =  "Password mismatch";
                return response()->json(['result' => $result], 422);
            }
        }else{
            $result['status'] = false; 
            $result['message'] = "User does not exist"; 
            $result['data'] = []; 
            return response()->json(['result' => $result], 422);
        }
    }

    public function profileDetails(Request $request)
    {
        $user = Auth::guard('appuser-api')->user();
        if($user){
            // dd($user);
            $userData["user_id"] = $user->id;
            $userData["name"] = $user->name;
            $userData["email"] = $user->email;
            $userData["mobile"] = $user->mobile;
            $userData["profile_image"] = $user->profile_image ? $user->profile_image : "";
            $userData["status"] = $user->status;

            $output = [
                'status' => true,
                'message' => 'User profile all data',
                'data' => $userData
            ];
            return response()->json($output, 200);
        }else{
            $output = [
                'status' => false,
                'message' => 'Unauthenticated',
                'data' => []
            ];
            return response()->json($output, 401);
        }
    }

    public function changePassword(Request $request)
    {
        $data = $request->all();
        $rules = [
            'old_password' => ['required'],
            'new_password' => ['required', 'min:8'],
            'confirm_password' => ['required', 'same:new_password']
        ];

        $message = [
            'old_password.required' => 'Old password field is required.',
            'new_password.required' => 'New password field is required.',
            'new_password.min' => 'New password use 8 digit minimum',
            'confirm_password.required' => 'Confirm password field is required.'
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            $response['status'] = false; 
            $response['message'] = "Validation errors";
            $response['error'] = $validator->errors();
            $response['data'] = []; 
            return response()->json(['result' => $response], 422);
        }
        
        try{
            if ((Hash::check(request('old_password'), Auth::guard('appuser-api')->user()->password)) == false) {
                $result['status'] = false; 
                $result['message'] = "Check your old password."; 
                $result['data'] = []; 
                return response()->json(['result' => $result], 400);
            } elseif ((Hash::check(request('new_password'), Auth::guard('appuser-api')->user()->password)) == true) {
                $result['status'] = false; 
                $result['message'] = "Please enter a password which is not similar then current password."; 
                $result['data'] = []; 
                return response()->json(['result' => $result], 400);
            } else {
                $userid = Auth::guard('appuser-api')->user()->id;
                Appuser::where('id', $userid)->update(['password' => Hash::make($data['new_password'])]);
                $result['status'] = true; 
                $result['message'] = "Password updated successfully."; 
                $result['data'] = []; 
                return response()->json(['result' => $result], 200);
            }
        }catch (\Exception $ex) {
            if (isset($ex->errorInfo[2])) {
                $msg = $ex->errorInfo[2];
            } else {
                $msg = $ex->getMessage();
            }
            $result['status'] = false;
            $result['message'] = $msg;
            $result['data'] = []; 
            return response()->json(['result' => $result], 400);
        }
    }

    public function forgotPassword(Request $request)
    {
        $data = $request->all();

        $rules = [
            'email' => ['required', 'email']
        ];
        $message = [
            'email.required' => 'Email field is required.',
            'email.email' => 'Email must be valid format.'
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            $response['status'] = false; 
            $response['message'] = "Validation errors";
            $response['error'] = $validator->errors();
            $response['data'] = []; 
            return response()->json(['result' => $response], 422);
        }

        try{
            // $user = Auth::guard('appuser-api')->user();
            $user = Appuser::where('email', $request->email)->first();
            if($user){
                // dd($user);
                $userId= $user->id;
                $userName = $user->name;
                $userEmail = $user->email;
                $userMobile = $user->mobile;

                $randomNumber = random_int(100000, 999999);
                $expireTime = now()->addMinutes(15);

                $mailData = [
                    'fullname' => $userName,
                    'otp' => $randomNumber
                ];
                //  dd($userEmail);
                $mailSent = Mail::to($userEmail)->send(new ForgotPassworMail($mailData));
                // dd($mailSent);
                Appuser::where('id', $userId)->update(['otp' => $randomNumber, 'otp_send_to' => 'email', 'otp_expire_at' => $expireTime]);
    
                $result['status']  =  true;
                $result['message'] =  "Send your otp on register email address.";
                $result['data']    =  [];
                return response()->json(['result' => $result], 200);
            }else{
                $result['status']  =  false;
                $result['message'] =  "Email does not exist.";
                $result['data']    =  [];
                return response()->json(['result' => $result], 422);
            }
        }catch (\Swift_TransportException $ex) {
            if (isset($ex->errorInfo[2])) {
                $msg = $ex->errorInfo[2];
            } else {
                $msg = $ex->getMessage();
            }
            $result['status'] = false;
            $result['message'] = $msg;
            $result['data'] = []; 
            return response()->json(['result' => $result], 400);
        }
    }

    public function verifyOtp(Request $request)
    {
        $data = $request->all();
        $rules = [
            'email' => ['required', 'email'],
            'verify-otp' => ['required']
        ];
        $message = [
            'email.required' => 'Email field is required.',
            'email.email' => 'Email must be valid format.',
            'verify-otp.required' => 'Verify otp field is required.'
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            $response['status'] = false; 
            $response['message'] = "Validation errors";
            $response['error'] = $validator->errors();
            $response['data'] = []; 
            return response()->json(['result' => $response], 422);
        }

        try{
            $user = Appuser::where('email', $request->email)->first();
            if($user){
                $userId= $user->id;
                $userOTP = $user->otp;
                $expireTime = $user->otp_expire_at;
                $currentTime = now();
                if($currentTime < $expireTime){
                    $dataOTP = $data['verify-otp'];
                    if($userOTP == $dataOTP){
                        $token = $user->createToken('user Token', ['appuser'])->accessToken;

                        $result['status']  =  true;
                        $result['message']  =  "Your otp matched successfully.";
                        $result['token']    =  $token;
                        return response()->json(['result' => $result], 200);
                    }else{
                        $result['status']  =  false;
                        $result['message']  =  "Invalid OTP. Please enter valid otp.";
                        $result['data']    =  [];
                        return response()->json(['result' => $result], 400);
                    }
                }else{
                    $result['status']  =  false;
                    $result['message']  =  "Your otp is expired so please send otp again.";
                    $result['data']    =  [];
                    return response()->json(['result' => $result], 401);
                }
                
            }else{
                $result['status']  =  false;
                $result['message'] =  "Email does not exist.";
                $result['data']    =  [];
                return response()->json(['result' => $result], 422);
            }
        }catch (\Exception $ex) {
            if (isset($ex->errorInfo[2])) {
                $msg = $ex->errorInfo[2];
            } else {
                $msg = $ex->getMessage();
            }
            $result['status'] = false;
            $result['message'] = $msg;
            $result['data'] = []; 
            return response()->json(['result' => $result], 400);
        }
    }

    public function changePasswordSingleParameter(Request $request)
    {
        $data = $request->all();
        $rules = [
            'new_password' => ['required', 'min:8'],
        ];

        $message = [
            'new_password.required' => 'New password field is required.',
            'new_password.min' => 'New password use 8 digit minimum',
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            $response['status'] = false; 
            $response['message'] = "Validation errors";
            $response['error'] = $validator->errors();
            $response['data'] = []; 
            return response()->json(['result' => $response], 422);
        }
        
        try{
            if ((Hash::check(request('new_password'), Auth::guard('appuser-api')->user()->password)) == true) {
                $result['status'] = false; 
                $result['message'] = "Please enter a password which is not similar then current password."; 
                $result['data'] = []; 
                return response()->json(['result' => $result], 400);
            } else {
                $userid = Auth::guard('appuser-api')->user()->id;
                Appuser::where('id', $userid)->update(['password' => Hash::make($data['new_password'])]);
                $result['status'] = true; 
                $result['message'] = "Password updated successfully."; 
                $result['data'] = []; 
                return response()->json(['result' => $result], 200);
            }
        }catch (\Exception $ex) {
            if (isset($ex->errorInfo[2])) {
                $msg = $ex->errorInfo[2];
            } else {
                $msg = $ex->getMessage();
            }
            $result['status'] = false;
            $result['message'] = $msg;
            $result['data'] = []; 
            return response()->json(['result' => $result], 400);
        }
    }
}