<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Admin;
use Illuminate\Http\Request;
use Validator, Auth, DB, Hash;

class AdminController extends Controller
{
    public function authenticate(Request $request) {

        $this->validate($request,[
            'email' => 'required|email',
            'password' => 'required'
        ]);

        if (Auth::guard('admin')->attempt(['email' => $request->email, 'password' => $request->password],$request->get('remember'))) {

            return redirect()->route('admin.pages.dashboard');

        } else {
            session()->flash('error','Either Email/Password is incorrect');
            return back()->withInput($request->only('email'));
        }

    }

    public function logout(Request $request) {
        Auth::guard('admin')->logout();
        
        $request->session()->flush();

        $request->session()->regenerate();

        return redirect('admin/login');
    }

    public function index()
    {
        // $getProfile = Admin::find(\Session::get('id'));
        $adminData = Admin::all();
        $adminPageVars = [
            //This is the title of my custom view.
            'pageTitle'=>'Admin List',
            'adminsListData'=>$adminData
        ];
        return view('admin.pages.users.user-list')->with($adminPageVars);
    }

    public function store(Request $request)
    {
        $data = $request->all();
        $rules = [
            'firstname' => ['required', 'string', 'min:3', 'max:50'],
            'lastname' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:admins'],
            'username' => ['required', 'string', 'min:2', 'max:255'],
            'password' => ['required', 'string', 'max:50'],
            'mobile' => ['required', 'string', 'min:10', 'max:10'],
            'roleId' => ['required'],
            'status' => ['required']
        ];

        $message = [
            'firstname.required' => 'First name field is required.',
            'lastname.required' => 'Last name field is required.',
            'email.required' => 'Email field is required.',
            'email.email' => 'Email field must be email address.',
            'username.required' => 'Username field is required.',
            'password.required' => 'Password field is required.',
            'mobile.required' => 'Mobile field is required.',
            'roleId.required' => 'Role field is required.',
            'status.required' => 'Status field is required.'
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            return redirect('admin/user')
                        ->withErrors($validator)
                        ->withInput();
        }

        $adminStore = new Admin;
        $adminStore->firstname = $data['firstname'];
        $adminStore->lastname = $data['lastname'];
        $adminStore->email = $data['email'];
        $adminStore->username = $data['username'];
        $adminStore->password = Hash::make($data['password']);
        $adminStore->mobile = $data['mobile'];
        $adminStore->role_id = $data['roleId'];
        $adminStore->status = $data['status'];

        $adminStore->save();

        return redirect('admin/displayuser/')->with('success','User added successfully.');
    }
}

