<?php

namespace App\Http\Controllers\School;

use App\Http\Controllers\Controller;
use App\Models\School;
use Illuminate\Http\Request;
use Validator, Auth, DB, Hash;

class SchoolController extends Controller
{
    public function authenticate(Request $request) {
        $this->validate($request,[
            'email' => 'required|email',
            'password' => 'required'
        ]);

        if (Auth::guard('school')->attempt(['email' => $request->email, 'password' => $request->password, 'status' => 707], $request->get('remember'))) {

            return redirect()->route('school.pages.dashboard');

        } else {
            session()->flash('error','Either Email/Password is incorrect');
            return back()->withInput($request->only('email'));
        }

    }

    public function store(Request $request)
    {
        $data = $request->all();
        // dd($data);
        $rules = [
            'school_name' => ['required', 'string', 'min:3', 'max:50'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:admins'],
            'password' => ['required', 'string', 'max:50'],
            'mobile' => ['required', 'string', 'min:10', 'max:10']
        ];

        $message = [
            'school_name.required' => 'School name field is required.',
            'email.required' => 'Email field is required.',
            'email.email' => 'Email field must be email address.',
            'password.required' => 'Password field is required.',
            'mobile.required' => 'Mobile field is required.',
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            return redirect('school/register')
                        ->withErrors($validator)
                        ->withInput();
        }

        $schoolStore = new School;
        $schoolStore->school_name = $data['school_name'];
        $schoolStore->email = $data['email'];
        $schoolStore->password = Hash::make($data['password']);
        $schoolStore->mobile = $data['mobile'];
        $schoolStore->alt_mobile = $data['alt_mobile'];
        $schoolStore->status = 707;

        $schoolStore->save();

        return redirect('school/register/')->with('success','Registration successfuly. The administrator will review the information that has been submitted and either approve or deny your request. Thanks for your patience.');
    }

    public function logout(Request $request) {
        Auth::guard('school')->logout();
        
        $request->session()->flush();

        $request->session()->regenerate();

        return redirect('school/login');
    }
}
