<?php

namespace App\Http\Controllers\School;

use App\Http\Controllers\Controller;
use App\Models\Teacher;
use Illuminate\Http\Request;
use Carbon\Carbon;
use Validator, DB, Hash, Auth;

class TeacherController extends Controller
{
    public function index()
    {
        $schoolId = Auth::id();
        $teacherData = DB::table('teachers')
                    ->whereIn('school_id', [ $schoolId])
                    ->get();
        $teacherDataArray = [
            //This is the title of my custom view.
            'pageTitle'=>'Teacher List',
            'teacherListData'=>$teacherData
        ];
        return view('school.pages.teachers.teacher-list')->with($teacherDataArray);
    }

    public function addTeacherForm()
    {
        return view('school.teachers.add-teacher');
    }

    public function store(Request $request)
    {
        $data = $request->all();
        // dd($data);
        $rules = [
            'firstName' => ['required', 'string', 'min:3', 'max:50'],
            'lastName' => ['required', 'string', 'min:3', 'max:50'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:admins'],
            // 'password' => ['required', 'string', 'max:50'],
            'mobile' => ['required', 'string', 'min:10', 'max:10'],
            'gender' => ['required', 'string', 'min:3', 'max:50'],
            'dob' => ['required'],
        ];

        $message = [
            'firstName.required' => 'First name field is required.',
            'lastName.required' => 'Last name field is required.',
            'email.required' => 'Email field is required.',
            'email.email' => 'Email field must be email address.',
            // 'password.required' => 'Password field is required.',
            'mobile.required' => 'Mobile field is required.',
            'gender.required' => 'Gender field is required.',
            'dob.required' => 'Date of Birth field is required.',
            // 'dob.date_format' => 'Date of Birth valid date format.',
        ];

        $validator = Validator::make($data, $rules, $message);
        if($validator->fails()) {
            return redirect('school/teacher')
                        ->withErrors($validator)
                        ->withInput();
        }
        $password = 'Temp@1234';
        $schoolId = Auth::id();

        $teacherStore = new Teacher;
        $teacherStore->school_id = $schoolId;
        $teacherStore->first_name = $data['firstName'];
        $teacherStore->last_name = $data['lastName'];
        $teacherStore->email = $data['email'];
        $teacherStore->password = Hash::make($password);
        $teacherStore->uid = $data['idNumber'];
        $teacherStore->mobile = $data['mobile'];
        $teacherStore->gender = $data['gender'];
        $teacherStore->dob = date('Y-m-d', strtotime($data['dob']));
        $teacherStore->bloodGroup = $data['bloodGroup'];
        $teacherStore->religion = $data['religion'];
        $teacherStore->address = $data['address'];
        $teacherStore->status = 707;
        $teacherStore->save();

        return redirect('school/displayteacher/')->with('success','Record added successfuly.');
    }
}
